16.76. cdist-type__install_reboot(7) — cdist 6.9.8 documentation

# 16.76. cdist-type__install_reboot(7)

## 16.76.1. NAME

cdist-type__install_reboot - run reboot

## 16.76.2. DESCRIPTION

This cdist type allows you to reboot a machine.

## 16.76.3. REQUIRED PARAMETERS

None

## 16.76.4. OPTIONAL PARAMETERS

None

## 16.76.5. EXAMPLES

    __install_reboot

## 16.76.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.76.7. COPYING

Copyright (C) 2011 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.